==> qmmp-plugin-pack-1.5.0.tar.bz2: qmmp-plugin-pack-1.5.0/src/Input/xmp/translations/xmp_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>DecoderXmpFactory</name>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="39"/>
        <source>XMP Plugin</source>
        <translation>XMP-liitännäinen</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="52"/>
        <source>Module Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="109"/>
        <source>About XMP Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="110"/>
        <source>Qmmp XMP Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="111"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Toteuttanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="112"/>
        <source>Compiled against libxmp-%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>XMP Plugin Settings</source>
        <translation>XMP-liitännäisen asetukset</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source> Amplification factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Stereo mixing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source> Interpolation type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Lowpass filter effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Use vblank timing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <source>Emulate Protracker 2.x FX9 bug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Sample rate:</source>
        <translation>Näytteenottotaajuus:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Nearest neighbor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Linear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Cubic spline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XmpMetaDataModel</name>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="52"/>
        <source>Volume scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="53"/>
        <source>Number of patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="54"/>
        <source>Number of tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="55"/>
        <source>Tracks per pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="56"/>
        <source>Number of instruments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="57"/>
        <source>Number of samples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="58"/>
        <source>Initial speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="59"/>
        <source>Initial BPM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="60"/>
        <source>Module length in patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="79"/>
        <source>Samples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="87"/>
        <source>Instruments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="92"/>
        <source>Comment</source>
        <translation>Kommentti</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-1.5.3.tar.bz2: qmmp-plugin-pack-1.5.3/src/Input/xmp/translations/xmp_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>DecoderXmpFactory</name>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="39"/>
        <source>XMP Plugin</source>
        <translation>XMP Plugin</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="52"/>
        <source>Module Files</source>
        <translation>Moduulitiedostot</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="109"/>
        <source>About XMP Audio Plugin</source>
        <translation>Tietoja: XMP Audio Plugin</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="110"/>
        <source>Qmmp XMP Audio Plugin</source>
        <translation>Qmmp XMP Audio Plugin</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="111"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="112"/>
        <source>Compiled against libxmp-%1</source>
        <translation>Koostettu libxmp-%1</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>XMP Plugin Settings</source>
        <translation>Asetukset XMP Plugin</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source> Amplification factor:</source>
        <translation>Vahvistuskerroin:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Stereo mixing:</source>
        <translation>Stereomiksaus:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source> Interpolation type:</source>
        <translation>Interpolointi tyyppi:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Lowpass filter effect</source>
        <translation>Lowpass suotimen efekti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Use vblank timing</source>
        <translation>Käytä ajoitukseen vblank</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <source>Emulate Protracker 2.x FX9 bug</source>
        <translation>Jäljittele Protracker 2.x FX9 vikaa</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Sample rate:</source>
        <translation>Taajuus:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Nearest neighbor</source>
        <translation>Lähin naapuri</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Linear</source>
        <translation>Lineaarinen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Cubic spline</source>
        <translation>Kuutio spline</translation>
    </message>
</context>
<context>
    <name>XmpMetaDataModel</name>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="52"/>
        <source>Volume scale</source>
        <translation>Voimakkuuden asteikko </translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="53"/>
        <source>Number of patterns</source>
        <translation>Kuvioiden määrä</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="54"/>
        <source>Number of tracks</source>
        <translation>Kappaleiden määrä</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="55"/>
        <source>Tracks per pattern</source>
        <translation>Kappaleita per kuvio</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="56"/>
        <source>Number of instruments</source>
        <translation>Instrumenttien määrä</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="57"/>
        <source>Number of samples</source>
        <translation>Näytteiden määrä</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="58"/>
        <source>Initial speed</source>
        <translation>Alkunopeus</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="59"/>
        <source>Initial BPM</source>
        <translation>Alkuperäinen BPM</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="60"/>
        <source>Module length in patterns</source>
        <translation>Moduulin kesto kuvioina</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="79"/>
        <source>Samples</source>
        <translation>Samplet</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="87"/>
        <source>Instruments</source>
        <translation>Soittimet</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="92"/>
        <source>Comment</source>
        <translation>Kommentti</translation>
    </message>
</context>
</TS>
